## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           cfn-lint
Summary:        CloudFormation Linter
Version:        1.22.2
Release:        %autorelease

# The entire source is MIT-0, except that some sources are derived from
# jsonschema https://pypi.org/project/jsonschema/, which is under an MIT
# license; the copyright and license notice is reproduced in the sources:
#   - src/cfnlint/jsonschema/_format.py
#   - src/cfnlint/jsonschema/_keywords.py
#   - src/cfnlint/jsonschema/_keywords_cfn.py
#   - src/cfnlint/jsonschema/_types.py
#   - src/cfnlint/jsonschema/_typing.py
#   - src/cfnlint/jsonschema/_utils.py
#   - src/cfnlint/jsonschema/exceptions.py
#   - src/cfnlint/jsonschema/protocols.py
#   - src/cfnlint/jsonschema/validators.py
#   - src/cfnlint/schema/resolver/_exceptions.py
#   - src/cfnlint/schema/resolver/_resolver.py
#   - src/cfnlint/schema/resolver/_utils.py
License:        MIT-0 AND MIT
# Additionally, two test files are Apache-2.0, but these are not included in
# the binary RPMs:
#   - test/fixtures/templates/quickstart/openshift.yaml
#   - test/fixtures/templates/quickstart/openshift_master.yaml
SourceLicense:  %{license} AND Apache-2.0
URL:            https://github.com/aws-cloudformation/cfn-lint
# While the PyPI sdist contains the tests since 0.76.0, we still need data and
# documentation files that are only available in the GitHub archive.
Source0:        %{url}/archive/v%{version}/cfn-lint-%{version}.tar.gz
# Man page written for Fedora in groff_man(7) format based on --help output
Source1:        cfn-lint.1

BuildSystem:            pyproject
BuildOption(install):   -l cfnlint
BuildOption(generate_buildrequires): -x full,graph,junit,sarif

BuildArch:      noarch

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

BuildRequires:  hardlink

# From tox.ini:
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist defusedxml}

# One function in cfnlint.maintenance calls “git grep”. It’s not entirely clear
# if this is really usable in a system-wide installation or not; it might be
# trying to operate on a git checkout of cfn-lint, which won’t be available. It
# doesn’t work for that reason when tested in
# TestUpdateDocumentation.test_update_docs, which is why there is no
# corresponding BuildRequires.
Recommends:     git-core

# Since this is an application rather than a library, we choose to carry weak
# dependencies on the extras so that users have access to all features by
# default.
Recommends:     cfn-lint+graph = %{version}-%{release}
Recommends:     cfn-lint+junit = %{version}-%{release}
Recommends:     cfn-lint+sarif = %{version}-%{release}

%py_provides python3-cfn-lint

# A number of files are forked from https://pypi.org/project/jsonschema/; see
# the comment above License for a list of these files.
Provides:       bundled(python3dist(jsonschema))

%description
Validate AWS CloudFormation yaml/json templates against the AWS CloudFormation
Resource Specification and additional checks. Includes checking valid values
for resource properties and best practices.


%pyproject_extras_subpkg -n cfn-lint full graph junit sarif


%install -a
# This saves, as of this writing, over 4 MiB in duplicate data files and
# __init__.py files. Because timestamp differences across source files are not
# meaningful (are not really properties of the individual files), and all
# timestamps are *nearly* the same, we elect to pass “-t” in order to hardlink
# more duplicate files, in exchange for ignoring/discarding these insignificant
# timestamp differences.  single filesystem.
hardlink -t '%{buildroot}%{python3_sitelib}/cfnlint'
install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 '%{SOURCE1}'


%check -a
# These tests want to make HTTP(S) requests to the Internet:
k="${k-}${k+ and }not (TestFormatters and test_sarif_formatter)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_2)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_3)"

# This test tries to use “git grep”, but there is no git repository.
k="${k-}${k+ and }not (TestUpdateDocumentation and test_update_docs)"

# This test expects graphviz/dot output to be identical, down to the order of
# properties, which is not a portable expectation.
k="${k-}${k+ and }not (TestTemplate and test_build_graph)"

# Tests fail if we parallelize with pytest-xdist… so don’t do that!
#
# LANG and AWS_DEFAULT_REGION are set as they are in tox.ini.
LANG=en_US.UTF-8 AWS_DEFAULT_REGION=us-east-1 %pytest -k "${k-}"


%files -f %{pyproject_files}
# We don’t provide a separate documentation package since all of the following
# documentation is still not very big. As of this writing, it totals ~325kB
# extracted and a couple dozen files, in the context of a base package that is
# >15MB extracted with several thousand files.
%doc CHANGELOG.md
%doc README.md
# Markdown
%doc docs/
%doc examples/

%{_bindir}/cfn-lint
%{_mandir}/man1/cfn-lint.1*


%changelog
## START: Generated by rpmautospec
* Mon Dec 16 2024 Packit <hello@packit.dev> - 1.22.2-1
- Update to 1.22.2 upstream release
- Resolves: rhbz#2332713

* Thu Dec 12 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.22.1-1
- Update to 1.22.1

* Wed Dec 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.22.0-2
- Add a SourceLicense field

* Wed Dec 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.22.0-1
- Update to 1.22.0

* Wed Dec 11 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.21.0-1
- Update to 1.21.0 (close RHBZ#2331237)

* Tue Dec 03 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.20.2-1
- Update to 1.20.2 (close RHBZ#2330041)

* Sun Dec 01 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.20.1-1
- Update to 1.20.1 (close RHBZ#2329049)

* Fri Nov 22 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.20.0-1
- Update to 1.20.0 (close RHBZ#2327143)

* Wed Nov 13 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.19.0-1
- Update to 1.19.0 upstream release
- Resolves: rhbz#2325673

* Sat Nov 09 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.18.4-1
- Update to 1.18.4

* Tue Oct 29 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.18.2-3
- F41+: Use the provisional declarative buildsystem

* Mon Oct 28 2024 Packit <hello@packit.dev> - 1.18.2-1
- Update to 1.18.2 upstream release
- Resolves: rhbz#2322232

* Mon Oct 21 2024 Packit <hello@packit.dev> - 1.18.1-1
- Update to 1.18.1 upstream release
- Resolves: rhbz#2320422

* Fri Oct 18 2024 Packit <hello@packit.dev> - 1.17.2-1
- Update to 1.17.2 upstream release
- Resolves: rhbz#2319817

* Thu Oct 17 2024 Packit <hello@packit.dev> - 1.17.1-1
- Update to 1.17.1 upstream release
- Resolves: rhbz#2319547

* Thu Oct 17 2024 Packit <hello@packit.dev> - 1.17.0-1
- Update to 1.17.0 upstream release
- Resolves: rhbz#2319415

* Thu Oct 10 2024 Packit <hello@packit.dev> - 1.16.1-1
- Update to 1.16.1 upstream release
- Resolves: rhbz#2317878

* Thu Oct 03 2024 Packit <hello@packit.dev> - 1.16.0-1
- Update to 1.16.0 upstream release
- Resolves: rhbz#2316389

* Mon Sep 30 2024 Packit <hello@packit.dev> - 1.15.2-1
- Update to 1.15.2 upstream release
- Resolves: rhbz#2315718

* Tue Sep 24 2024 Packit <hello@packit.dev> - 1.15.1-1
- Update to 1.15.1 upstream release
- Resolves: rhbz#2314474

* Mon Sep 23 2024 Packit <hello@packit.dev> - 1.15.0-1
- Update to 1.15.0 upstream release
- Resolves: rhbz#2314261

* Thu Sep 19 2024 Packit <hello@packit.dev> - 1.14.2-1
- Update to 1.14.2 upstream release
- Resolves: rhbz#2313594

* Tue Sep 17 2024 Packit <hello@packit.dev> - 1.14.1-1
- Update to 1.14.1 upstream release
- Resolves: rhbz#2312981

* Mon Sep 16 2024 Packit <hello@packit.dev> - 1.14.0-1
- Update to 1.14.0 upstream release
- Resolves: rhbz#2312636

* Fri Sep 13 2024 Packit <hello@packit.dev> - 1.13.0-1
- Update to 1.13.0 upstream release
- Resolves: rhbz#2312258

* Fri Sep 06 2024 Packit <hello@packit.dev> - 1.12.4-1
- Update to 1.12.4 upstream release
- Resolves: rhbz#2310342

* Wed Sep 04 2024 Packit <hello@packit.dev> - 1.12.3-1
- Update to 1.12.3 upstream release
- Resolves: rhbz#2310084

* Wed Sep 04 2024 Packit <hello@packit.dev> - 1.12.2-1
- Update to 1.12.2 upstream release
- Resolves: rhbz#2309531

* Mon Sep 02 2024 Packit <hello@packit.dev> - 1.11.1-1
- Update to 1.11.1 upstream release
- Resolves: rhbz#2309014

* Tue Aug 27 2024 Packit <hello@packit.dev> - 1.11.0-1
- Update to 1.11.0 upstream release
- Resolves: rhbz#2308255

* Fri Aug 16 2024 Packit <hello@packit.dev> - 1.10.3-1
- Update to 1.10.3 upstream release
- Resolves: rhbz#2305358

* Thu Aug 15 2024 Packit <hello@packit.dev> - 1.10.2-1
- Update to 1.10.2 upstream release
- Resolves: rhbz#2305234

* Tue Aug 13 2024 Packit <hello@packit.dev> - 1.10.1-1
- Update to 1.10.1 upstream release
- Resolves: rhbz#2304234

* Fri Aug 09 2024 Packit <hello@packit.dev> - 1.9.7-1
- Update to 1.9.7 upstream release
- Resolves: rhbz#2303879

* Thu Aug 08 2024 Packit <hello@packit.dev> - 1.9.6-1
- Update to 1.9.6 upstream release
- Resolves: rhbz#2303786

* Mon Aug 05 2024 Packit <hello@packit.dev> - 1.9.5-1
- Update to 1.9.5 upstream release
- Resolves: rhbz#2302933

* Sun Aug 04 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.9.4-1
- Update to 1.9.4 upstream release
- Resolves: rhbz#2302721

* Thu Aug 01 2024 Packit <hello@packit.dev> - 1.9.3-1
- Update to 1.9.3 upstream release
- Resolves: rhbz#2302374

* Wed Jul 31 2024 Packit <hello@packit.dev> - 1.9.2-1
- Update to 1.9.2 upstream release
- Resolves: rhbz#2302090

* Tue Jul 30 2024 Packit <hello@packit.dev> - 1.9.1-1
- Update to 1.9.1 upstream release
- Resolves: rhbz#2301728

* Mon Jul 29 2024 Packit <hello@packit.dev> - 1.9.0-1
- Update to 1.9.0 upstream release
- Resolves: rhbz#2300816

* Fri Jul 19 2024 Packit <hello@packit.dev> - 1.8.2-1
- Update to 1.8.2 upstream release
- Resolves: rhbz#2298823

* Thu Jul 18 2024 Packit <hello@packit.dev> - 1.8.1-1
- Update to 1.8.1 upstream release
- Resolves: rhbz#2298456

* Wed Jul 17 2024 Packit <hello@packit.dev> - 1.8.0-1
- Update to 1.8.0 upstream release
- Resolves: rhbz#2298456

* Wed Jul 17 2024 Packit <hello@packit.dev> - 1.7.2-1
- Update to 1.7.2 upstream release
- Resolves: rhbz#2298456

* Wed Jul 17 2024 Packit <hello@packit.dev> - 1.7.1-1
- Update to 1.7.1 upstream release
- Resolves: rhbz#2298401

* Tue Jul 16 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.7.0-2
- Justify and skip a failing test

* Tue Jul 16 2024 Packit <hello@packit.dev> - 1.7.0-1
- Update to 1.7.0 upstream release
- Resolves: rhbz#2298249

* Mon Jul 15 2024 Packit <hello@packit.dev> - 1.6.1-1
- Update to 1.6.1 upstream release
- Resolves: rhbz#2297815

* Wed Jul 10 2024 Packit <hello@packit.dev> - 1.5.3-1
- Update to 1.5.3 upstream release
- Resolves: rhbz#2297171

* Tue Jul 09 2024 Packit <hello@packit.dev> - 1.5.2-1
- Update to 1.5.2 upstream release
- Resolves: rhbz#2296866

* Mon Jul 08 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.5.1-1
- Update to 1.5.1 (close RHBZ#2296370)

* Tue Jul 02 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.5.0-1
- Update to 1.5.0
- Add metapackage for full extra

* Sun Jun 30 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.4.2-1
- Update to 1.4.2 (close RHBZ#2178217)
- Add metapackages for graph, junit, and sarif extras

* Sat Jun 29 2024 Python Maint <python-maint@redhat.com> - 0.87.7-2
- Rebuilt for Python 3.13

* Thu Jun 20 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.87.7-1
- Update to 0.87.7

* Tue May 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.87.4-1
- Update to 0.87.4

* Fri May 17 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.87.2-1
- Update to 0.87.2

* Thu May 09 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.87.1-1
- Update to 0.87.1

* Thu Mar 28 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.86.1-1
- Update to 0.86.1

* Fri Mar 15 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.86.0-3
- Hardlink more duplicate files, ignoring insignificant timestamp
  differences

* Fri Mar 08 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.86.0-1
- Update to 0.86.0

* Thu Feb 15 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.85.1-1
- Update to 0.85.1

* Sat Feb 03 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.85.0-1
- Update to 0.85.0

* Mon Jan 29 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.83.8-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Jan 23 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.83.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.83.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Jan 09 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.8-1
- Update to 0.83.8

* Fri Jan 05 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.7-1
- Update to 0.83.7

* Fri Jan 05 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.6-1
- Update to 0.83.6

* Fri Dec 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.5-2
- Assert that %%pyproject_files contains a license file

* Thu Dec 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.5-1
- Update to 0.83.5

* Wed Dec 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.4-1
- Update to 0.83.4

* Thu Nov 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.3-1
- Update to 0.83.3

* Tue Nov 14 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.2-1
- Update to 0.83.2

* Mon Nov 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.1-1
- Update to 0.83.1

* Tue Oct 24 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.83.0-1
- Update to 0.83.0

* Mon Sep 25 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.80.3-1
- Update to 0.80.3

* Wed Sep 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.80.2-1
- Update to 0.80.2

* Sat Sep 16 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.11-1
- Update to 0.79.11

* Fri Sep 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.8-1
- Update to 0.79.8

* Sat Aug 26 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.7-1
- Update to 0.79.7

* Sat Aug 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.6-1
- Update to 0.79.6

* Sat Jul 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.5-1
- Update to 0.79.5

* Sat Jul 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.78.1-1
- Update to 0.78.1

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.77.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 04 2023 Python Maint <python-maint@redhat.com> - 0.77.10-2
- Rebuilt for Python 3.12

* Tue Jun 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.10-1
- Update to 0.77.10

* Wed Apr 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.2-1
- Update to 0.77.2 (close RHBZ#2188056)

* Tue Apr 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.1-1
- Update to 0.77.1 (close RHBZ#2187434)

* Mon Apr 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.0-1
- Update to 0.77.0 (close RHBZ#2185615)

* Mon Apr 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.76.2-1
- Update to 0.76.2 (close RHBZ#2184199)

* Wed Mar 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.76.1-1
- Update to 0.76.1 (close RHBZ#2182154)
- Improve pygraphviz/pydot dependency and stop skipping the test

* Mon Mar 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.75.1-1
- Update to 0.75.1 (close RHBZ#2180137)

* Sun Mar 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.75.0-1
- Update to 0.75.0 (close RHBZ#2179144)

* Wed Mar 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.3-1
- Update to 0.74.3 (close RHBZ#2178217)

* Mon Mar 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.2-1
- Update to 0.74.2 (close RHBZ#2177880)

* Mon Mar 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.1-1
- Update to 0.74.1 (close RHBZ#2175858)

* Tue Feb 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.0-1
- Update to 0.74.0 (close RHBZ#2173746)

* Fri Feb 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.2-1
- Update to 0.73.2 (close RHBZ#2170935)

* Sat Feb 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.1-1
- Update to 0.73.1 (close RHBZ#2169011)

* Fri Feb 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.0-1
- Update to 0.73.0 (close RHBZ#2165108)

* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.72.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jan 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.9-1
- Update to 0.72.9 (close RHBZ#2161737)

* Wed Jan 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.8-1
- Update to 0.72.8 (close RHBZ#2160267)

* Mon Jan 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.7-1
- Update to 0.72.7 (close RHBZ#2159513)

* Wed Jan 04 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.6-1
- Update to 0.72.6 (close RHBZ#2158030)

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.5-2
- Leaf package: remove i686 support

* Fri Dec 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.5-1
- Update to 0.72.5 (close RHBZ#2154353)

* Thu Dec 15 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.4-1
- Update to 0.72.4 (close RHBZ#2154101)

* Wed Dec 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.3-1
- Update to 0.72.3 (close RHBZ#2153591)

* Tue Dec 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.2-1
- Update to 0.72.2 (close RHBZ#2151048)

* Sun Nov 27 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.1-1
- Update to 0.72.1 (close RHBZ#2148742)

* Fri Nov 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.0-1
- Update to 0.72.0 (close RHBZ#2144968)

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.71.1-1
- Update to 0.71.1 (close RHBZ#2142656)

* Tue Nov 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.71.0-1
- Update to 0.71.0 (close RHBZ#2140725)

* Mon Oct 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.70.0-1
- Update to 0.70.0 (close RHBZ#2138931)

* Wed Oct 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.69.1-1
- Update to 0.69.1 (close RHBZ#2137688)

* Sat Oct 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.68.1-1
- Update to 0.68.1 (close RHBZ#2136904)

* Wed Oct 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.68.0-1
- Update to 0.68.0 (close RHBZ#2135951)
- Drop CODE_OF_CONDUCT.md and CONTRIBUTING.md from the package, as they are
  mostly relevant to upstream development

* Mon Oct 10 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.67.0-1
- Update to 0.67.0 (close RHBZ#2133469)

* Wed Oct 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.66.1-1
- Update to 0.66.1 (close RHBZ#2131077)

* Tue Sep 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.65.1-1
- Update to 0.65.1 (close RHBZ#2128106)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.65.0-1
- Update to 0.65.0 (close RHBZ#2126573)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.64.1-2
- Man page typo fixes

* Sun Sep 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.64.1-1
- Update to 0.64.1 (close RHBZ#2124643)

* Fri Sep 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.2-2
- Support for jsonschema 4.x is now via upstream PR#2336

* Wed Aug 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.2-1
- Update to 0.63.2 (close RHBZ#2122822)

* Tue Aug 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.1-1
- Update to 0.63.1 (close RHBZ#2122760)

* Thu Aug 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.0-1
- Update to 0.63.0 (close RHBZ#2119854)

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.5-1
- Update to 0.61.5 (close RHBZ#2117743)

* Sun Jul 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.4-2
- Confirm that License is SPDX MIT-0 (no License field change)

* Fri Jul 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.4-1
- Update to 0.61.4 (close RHBZ#2112420)

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.61.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.3-1
- Update to 0.61.3 (close RHBZ#2108237)

* Tue Jul 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.2-1
- Update to 0.61.2 (close RHBZ#2105446)

* Wed Jun 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-3
- Correctly allow jsonschema 4.x (close RHBZ#2101852)

* Tue Jun 28 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-2
- Allow jsonschema 4.x (close RHBZ#2101852)

* Thu Jun 23 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-1
- Update to 0.61.1 (close RHBZ#2100086)

* Wed Jun 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.0-2
- Rebuilt for Python 3.11 (close RHBZ#2098682)

* Wed Jun 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.0-1
- Update to 0.61.0 (close RHBZ#2092104)

* Fri May 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.60.1-1
- Update to 0.60.1 (close RHBZ#2088569)

* Fri May 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.60.0-1
- Update to 0.60.0 (close RHBZ#2085999)

* Mon May 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.1-1
- Update to 0.59.1 (close RHBZ#2081089)

* Wed Apr 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.0-2
- Install man page directly rather than copying to source tree first

* Wed Apr 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.0-1
- Update to 0.59.0 (close RHBZ#2074634)

* Tue Mar 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.4-1
- Update to 0.58.4 (close RHBZ#2066498)

* Tue Mar 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.3-1
- Update to 0.58.3 (close RHBZ#2061852)

* Sat Feb 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.2-1
- Update to 0.58.1 (close RHBZ#2058798)

* Tue Feb 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.1-1
- Update to 0.58.1 (close RHBZ#2056627)

* Mon Jan 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.0-1
- Update to 0.58.0 (close RHBZ#2048684)

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.57.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.57.0-1
- Update to 0.57.0 (close RHBZ#2042187)

* Wed Jan 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.56.4-1
- Update to 0.56.3 (close RHBZ#2039002)

* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.56.3-1
- Initial package (close RHBZ#2033083)
## END: Generated by rpmautospec
